@@ -1,14 +1,13 @@
-from cProfile import run
-from email import message
-from re import S
-import tkinter
 import datetime
 import threading
 import multiprocessing
-from tkinter import ttk
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg, NavigationToolbar2Tk
 from matplotlib.pyplot import text, switch_backend
-from numpy import pad
+
+import tkinter
+from tkinter import ttk, messagebox
+from tkinter.filedialog import askopenfilename, asksaveasfilename
+
 
 from . import _structs, _funcs, _srcs
 from .. import scheduller
